package controllers

import javax.inject._
import play.api._
import play.api.mvc._

import models.MongoDBClient
import org.mongodb.scala.{Document}
import scala.concurrent.ExecutionContext.Implicits.global
import scala.concurrent.{Future, Await, TimeoutException}
import scala.concurrent.duration._

/**
 * This controller creates an `Action` to handle HTTP MongoDB requests.
 */
@Singleton
class MongoTestController @Inject()(val controllerComponents: ControllerComponents) extends BaseController {

    /**
    * Create an Action to test the Mongo Client.
    */
    def index() = Action { implicit request: Request[AnyContent] =>
        println("MongoController")

        var database_name = "{DATABASE_NAME}"
        var collection_name = "{COLLECTION_NAME}"

        var mongo = new MongoDBClient()

        // Sequentially waits for Future objects to complete before calling next method
        val result: Future[Seq[Document]] = for {
            db <- mongo.getDatabase(database_name)
            collection <- mongo.getCollection(db, collection_name)
            findResult <- mongo.find(collection)
        } yield findResult


        try {
            // Wait for 10 seconds for the Future to complete
            val resultCompleted = Await.result(result, 4.seconds)

            val jsonResult: Seq[String] = resultCompleted.map(doc => doc.toJson())
            Ok(jsonResult.toString())
        } catch {
            case e: TimeoutException =>
                BadRequest("Request timed out")
        }
    }
}
